pub(crate) struct LayoutRoot<'dom> {
node: ServoLayoutNode<'dom>,
}Expand description
A data structure to track a layout root.
Layout roots are places in the fragment tree where fragment tree layout can start. These are fragments that isolate fragment damage from their ancestors sufficiently that their ancestors can be preserved from one fragment tree layout to the next. Currently, this only includes absolutely-or-fixed-positioned fragments that do not have any escaping fixed position fragments..
During damage propagation, upward flowing fragment tree Relayout damage can be
converted into DescendantCollectedAsLayoutRoot damage. When an ancestor of a layout
root has fragment tree layout damage, DescendantCollectedAsLayoutRoot damage is
converted back into Relayout and propagated up to the next layout root or the root
of the DOM.
This is only possible because the damage propagation traversal ensures that damage
above the absolute (which might shift its static position) is converted back into
Relayout damage. This means that the absolute should be placed with the fully
adjusted static positioning rectangle between two layouts.
It’s possible that upon laying out a layout root again, a new fixed position element has started to escape from the layout root. In that case, a full fragment tree layout becomes necessary to rebuild the fragment properly.
Fields
node: ServoLayoutNode<'dom>Implementations
Sourceimpl LayoutRoot<'_>
impl LayoutRoot<'_>
pub(crate) fn try_layout(&self, layout_context: &LayoutContext<'_>) -> bool